%global __requires_exclude ^/usr/bin/repl-monitor.pl


%global pkgname   dirsrv

# systemd support
%global groupname %{pkgname}.target

Summary:          389 Administration Server (admin)
Name:             389-admin
Version:          1.1.42
Release:          %mkrel 11
License:          GPLv2 and ASL 2.0
URL:              http://port389.org/
Group:            System/Servers

BuildRequires:    pkgconfig(nspr)
BuildRequires:    pkgconfig(nss)
BuildRequires:    openldap-devel
BuildRequires:    pkgconfig(libsasl2)
BuildRequires:    icu
BuildRequires:    libicu-devel
BuildRequires:    apache-devel
BuildRequires:    pkgconfig(apr-1)
BuildRequires:    apache-mod_nss
BuildRequires:    pkgconfig(389-adminutil) >= 1.1.21

Requires:         389-ds-base
Requires:         apache-mod_nss
Requires:         389-adminutil >= 1.1.21

# this is needed for using semanage from our setup scripts
Requires:         policycoreutils-python-utils

# the following are needed for some of our scripts
Requires:         perl-Mozilla-LDAP
Requires:         nss

# for systemd
Requires(post):  systemd-units
Requires(preun): systemd-units
Requires(postun): systemd-units

Source0:          http://port389.org/sources/%{name}-%{version}%{?prerel}.tar.bz2
# 389-admin-git.sh should be used to generate the source tarball from git
Source1:          %{name}-git.sh
Patch0:           mageia-group.patch
Patch1:           389-admin-1.1.35-link.patch
Patch2:           mod_nss.patch

%description
389 Administration Server is an HTTP agent that provides management features
for 389 Directory Server.  It provides some management web apps that can
be used through a web browser.  It provides the authentication, access control,
and CGI utilities used by the console.

%prep
%setup -q -n %{name}-%{version}%{?prerel}
%autopatch -p1

%build
autoreconf -fi
%configure \
           --disable-rpath \
           --disable-static \
           --with-openldap \
           --with-systemdsystemunitdir=%{_unitdir} \
           --with-systemddirsrvgroupname=%{groupname} \
           --with-modnss-bin=%{_libexecdir}


# Generate symbolic info for debuggers
export XCFLAGS=$RPM_OPT_FLAGS

%ifarch x86_64
export USE_64=1
%endif

%make_build

%install
%make_install

# make console jars directory
mkdir -p %{buildroot}%{_datadir}/%{pkgname}/html/java

#remove libtool and static libs
rm -f %{buildroot}%{_libdir}/*.so
rm -f %{buildroot}%{_libdir}/*.la
rm -f %{buildroot}%{_libdir}/%{pkgname}/modules/*.la

%pre -p <lua>
-- save ownership/permissions on the dirs/files that rpm changes
-- if these don't exist, the vars will be nil
%{pkgname}admin_adminserv = posix.stat('%{_sysconfdir}/%{pkgname}/admin-serv')
%{pkgname}admin_consoleconf = posix.stat('%{_sysconfdir}/%{pkgname}/admin-serv/console.conf')

%post -p <lua>
-- do the usual daemon post setup stuff
os.execute('/bin/systemctl preset %{pkgname}-admin.service >/dev/null 2>&1 || :')
os.execute('/sbin/ldconfig')
-- restore permissions if upgrading
if %{pkgname}admin_adminserv then
    posix.chmod('%{_sysconfdir}/%{pkgname}/admin-serv', %{pkgname}admin_adminserv.mode)
    posix.chown('%{_sysconfdir}/%{pkgname}/admin-serv', %{pkgname}admin_adminserv.uid, %{pkgname}admin_adminserv.gid)
end
if %{pkgname}admin_consoleconf then
    posix.chmod('%{_sysconfdir}/%{pkgname}/admin-serv/console.conf', %{pkgname}admin_consoleconf.mode)
    posix.chown('%{_sysconfdir}/%{pkgname}/admin-serv/console.conf', %{pkgname}admin_consoleconf.uid, %{pkgname}admin_consoleconf.gid)
end

%preun
%_preun_service %{pkgname}-admin


%files
%doc LICENSE
%dir %{_sysconfdir}/%{pkgname}/admin-serv
%config(noreplace)%{_sysconfdir}/%{pkgname}/admin-serv/*.conf
%{_datadir}/%{pkgname}
%config(noreplace)%{_sysconfdir}/sysconfig/%{pkgname}-admin
%{_unitdir}/%{pkgname}-admin.service
%{_sbindir}/*
%{_libdir}/*.so.*
%{_libdir}/%{pkgname}
%{_mandir}/man8/*


%changelog
* Wed Nov 16 2022 kekepower <kekepower> 1.1.42-11.mga9
+ Revision: 1907952
- Bump rel for rebuild

* Wed Mar 30 2022 umeabot <umeabot> 1.1.42-10.mga9
+ Revision: 1834058
- Mageia 9 Mass Rebuild

* Sun May 10 2020 wally <wally> 1.1.42-9.mga8
+ Revision: 1582601
- update policycoreutils requires

* Tue Feb 11 2020 umeabot <umeabot> 1.1.42-8.mga8
+ Revision: 1488934
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%configure2_5x

* Tue Aug 28 2018 daviddavid <daviddavid> 1.1.42-7.mga7
+ Revision: 1255194
- rebuild for new icu

* Fri Dec 29 2017 wally <wally> 1.1.42-6.mga7
+ Revision: 1186957
- rebuild for new icu

* Wed Mar 15 2017 mrambo3501 <mrambo3501> 1.1.42-5.mga6
+ Revision: 1092667
- Rebuild for icu-58.2

* Sat Jan 28 2017 akien <akien> 1.1.42-4.mga6
+ Revision: 1083828
- Rebuild for buildsystem issue

* Wed Feb 10 2016 umeabot <umeabot> 1.1.42-3.mga6
+ Revision: 953045
- Mageia 6 Mass Rebuild

* Tue Sep 08 2015 spuhler <spuhler> 1.1.42-2.mga6
+ Revision: 874076
- bmup rel. as it was built before
- added --with-modnss-bin=%%{_libexecdir} to configure
  * upstream moved the pcache in mod_nss to %%{_libexecdir}
  * but did not so in this package

* Mon Jun 22 2015 spuhler <spuhler> 1.1.42-1.mga6
+ Revision: 838820
- upgrade to vers. 1.1.42

* Sun Mar 22 2015 spuhler <spuhler> 1.1.38-2.mga5
+ Revision: 819104
- rebuilt with 389-adminutil-devel >= 1.1.21
- added requires 389-adminutil >= 1.1.21
  * otherwise deamon will not start

* Thu Mar 19 2015 spuhler <spuhler> 1.1.38-1.mga5
+ Revision: 818935
- upgrade to vers. 1.1.38
  * solves security issue in Bug #15467, CVE-2015-0233
  * solves a lot of bugs (upstream)

* Mon Mar 09 2015 spuhler <spuhler> 1.1.35-8.mga5
+ Revision: 818236
- added mod_nss.patch
  * nssmodule could not be found because of wrong name in http.conf
- removed "--with-selinux"  in configure
 * we do not provide selinux

* Wed Feb 18 2015 spuhler <spuhler> 1.1.35-7.mga5
+ Revision: 815698
- fixed macro in %%preun

* Wed Feb 18 2015 spuhler <spuhler> 1.1.35-6.mga5
+ Revision: 815623
- fixed macro in %%preun

* Sat Jan 03 2015 spuhler <spuhler> 1.1.35-5.mga5
+ Revision: 808322
- added %%global __requires_exclude ^/usr/bin/repl-monitor.pl
  * It's provided in Requires: 389-ds-base
  * But urpmi complains it as a requires

* Fri Dec 26 2014 umeabot <umeabot> 1.1.35-4.mga5
+ Revision: 806276
- Second Mageia 5 Mass Rebuild
- Mageia 5 Mass Rebuild
- Mageia 4 Mass Rebuild

* Tue Aug 27 2013 spuhler <spuhler> 1.1.35-1.mga4
+ Revision: 472434
- upgrade to vers. 1.1.35
  * removed admin_detection patch, built into the new source

* Tue Aug 27 2013 luigiwalser <luigiwalser> 1.1.34-2.mga4
+ Revision: 472068
- rebuild for cyrus-sasl

* Fri Aug 16 2013 spuhler <spuhler> 1.1.34-1.mga4
+ Revision: 467015
- upgrade to version 1.1.34
- removed 389-admin-1.1.31-pkgconfig-usage.patch
- added admin-detection.patch
  * based on Fedora 0001-Ticket-47465-problem-with-389-adminutil-detection-in.patch

* Fri Aug 16 2013 fwang <fwang> 1.1.31-5.mga4
+ Revision: 467002
- deal with empty adminutil_lib
- bump rel
- fix pkgconfig usage

* Mon May 27 2013 fwang <fwang> 1.1.31-4.mga4
+ Revision: 428593
- update link patch
- fix linkage
- rebuild for new icu
- rebuild for new icu

* Mon Mar 04 2013 spuhler <spuhler> 1.1.31-2.mga4
+ Revision: 401363
- added mageia-group.patch

* Sat Mar 02 2013 spuhler <spuhler> 1.1.31-1.mga3
+ Revision: 400964
- upgrade to version 1.1.31 to work with apache-2.4

* Fri Jan 11 2013 umeabot <umeabot> 1.1.30-5.mga3
+ Revision: 345046
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Fri Nov 09 2012 fwang <fwang> 1.1.30-4.mga3
+ Revision: 316606
- rebuild for update icu

* Tue Nov 06 2012 fwang <fwang> 1.1.30-3.mga3
+ Revision: 314751
- rebuild for new icu

* Mon Oct 29 2012 spuhler <spuhler> 1.1.30-2.mga3
+ Revision: 311386
- Requires changed from nss-tools to nss
  We have most of the nss-tools files in nss
  bumped rel

* Sun Oct 28 2012 spuhler <spuhler> 1.1.30-1.mga3
+ Revision: 311087
- cleaned spec and corrected group
- imported package 389-admin

